@@ -21,17 +21,17 @@ class CRL(ow_compound_optical_element.CompoundOpticalElement):
 
     nlenses = Setting(30)
     slots_empty = Setting(0)
-    thickness = Setting(625e-4)
+    thickness = Setting(2.5)
 
     p = Setting(0.0)
     q = Setting(0.0)
     surface_shape = Setting(1)
-    convex_to_the_beam = Setting(1)
+    convex_to_the_beam = Setting(0)
 
     has_finite_diameter = Setting(0)
     diameter = Setting(0.0)
 
-    is_cylinder = Setting(1)
+    is_cylinder = Setting(0)
     cylinder_angle = Setting(0.0)
 
     ri_calculation_mode = Setting(0)
@@ -39,8 +39,8 @@ class CRL(ow_compound_optical_element.CompoundOpticalElement):
     refraction_index = Setting(1.0)
     attenuation_coefficient = Setting(0.0)
 
-    radius = Setting(500e-2)
-    interthickness = Setting(0.001)
+    radius = Setting(0.1)
+    interthickness = Setting(0.03)
 
     use_ccc = Setting(0)
 
@@ -102,7 +102,7 @@ class CRL(ow_compound_optical_element.CompoundOpticalElement):
                      items=["No", "Yes"], sendSelectedValue=False, orientation="horizontal")
 
         gui.comboBox(oasysgui.widgetBox(lens_box, "", addSpace=False, orientation="vertical", height=40),
-                     self, "convex_to_the_beam", label="Convexity of the 1st interface exposed to the\nbeam (the 2nd interface has opposite convexity)",
+                     self, "convex_to_the_beam", label="Convexity of 1st interface exposed to the\nbeam (2nd interface has opposite convexity)",
                      labelWidth=310,
                      items=["No", "Yes"], sendSelectedValue=False, orientation="horizontal")
 
@@ -214,21 +214,22 @@ class CRL(ow_compound_optical_element.CompoundOpticalElement):
     ############################################################
 
     def populateFields(self, shadow_oe):
-        shadow_oe._oe.append_crl(p0=self.p,
-                                 q0=self.q,
-                                 nlenses=self.nlenses,
-                                 slots_empty=self.slots_empty,
-                                 thickness=self.thickness,
-                                 surface_shape=self.get_surface_shape(),
-                                 convex_to_the_beam=self.convex_to_the_beam,
-                                 diameter=self.get_diameter(),
-                                 cylinder_angle=self.get_cylinder_angle(),
-                                 prerefl_file=self.get_prerefl_file(),
-                                 refraction_index=self.refraction_index,
-                                 attenuation_coefficient=self.attenuation_coefficient,
-                                 radius=self.radius,
-                                 interthickness=self.interthickness,
-                                 use_ccc=self.use_ccc)
+        if self.nlenses > 0:
+            shadow_oe._oe.append_crl(p0=self.p,
+                                     q0=self.q,
+                                     nlenses=self.nlenses,
+                                     slots_empty=self.slots_empty,
+                                     thickness=self.thickness,
+                                     surface_shape=self.get_surface_shape(),
+                                     convex_to_the_beam=self.convex_to_the_beam,
+                                     diameter=self.get_diameter(),
+                                     cylinder_angle=self.get_cylinder_angle(),
+                                     prerefl_file=self.get_prerefl_file(),
+                                     refraction_index=self.refraction_index,
+                                     attenuation_coefficient=self.attenuation_coefficient,
+                                     radius=self.radius,
+                                     interthickness=self.interthickness,
+                                     use_ccc=self.use_ccc)
 
     def checkFields(self):
         congruence.checkPositiveNumber(self.nlenses, "Number of lenses")
